@@ -180,9 +180,13 @@ void BootMan::install(const QStringList &cmdextra)
 
             // Copy fallback files (not copied above because of --no-nvram switch).
             if (espdev != nullptr) {
-                const QString &espdst = espdev->mountPoint() + "/EFI/"_L1;
-                const QString &espsrc = espdst + loaderID;
-                proc.exec(u"cp"_s, {u"-p"_s, espsrc + "/fbx64.efi"_L1, espdst + "BOOT/"_L1});
+                QString espdst = espdev->mountPoint() + "/EFI/"_L1;
+                QString espsrc = espdst + loaderID;
+                QString fbx64efi = espsrc + "/fbx64.efi";
+                //file check is on /mnt/antiX as this command does not act in the chroot
+                if (QFile("/mnt/antiX" + fbx64efi).exists()) {
+                    proc.exec(u"cp"_s, {u"-p"_s, fbx64efi, espdst + "BOOT/"_L1});
+                }
                 core.mkpath("/mnt/antiX"_L1 + espdst + "debian/"_L1);
                 proc.exec(u"cp"_s, {u"-p"_s, espsrc + "/grub.cfg"_L1, espdst + "debian/"_L1});
             }
@@ -192,7 +196,7 @@ void BootMan::install(const QStringList &cmdextra)
             // Remove old boot variables of the same label.
             proc.exec(u"efibootmgr"_s, {}, nullptr, true);
             const QStringList &existing = proc.readOutLines();
-            static const QRegularExpression regex(u"^Boot([0-9A-F]{4})\\*?\\s(.*)$"_s);
+            static const QRegularExpression regex(u"^Boot([0-9A-F]{4})\\*?\\s(.*)\\t.*$"_s);
             for (const QString &entry : existing) {
                 const QRegularExpressionMatch &match = regex.match(entry);
                 if (match.hasMatch() && match.captured(2) == loaderLabel) {
