@@ -41,7 +41,7 @@ public:
     };
     class Section;
 
-    MProcess(QObject *parent = Q_NULLPTR);
+    MProcess(QObject *parent = nullptr);
     void setupUI(class QListWidget *listLog, class QProgressBar *progInstall) noexcept;
     bool exec(const QString &program, const QStringList &arguments = {},
         const QByteArray *input = nullptr, bool needRead = false);
@@ -52,27 +52,19 @@ public:
     void halt(bool exception = false) noexcept;
     void unhalt() noexcept;
     bool halted() const noexcept { return halting!=NO_HALT; }
+    bool checkHalt(); // Like halted() but throws an exception if THROW_HALT.
     // User interface
     static QString joinCommand(const QString &program, const QStringList &arguments) noexcept;
-    class QListWidgetItem *log(const QString &text, const enum LogType type = LOG_LOG) noexcept;
+    class QListWidgetItem *log(const QString &text, const enum LogType type = LOG_LOG, bool save = true) noexcept;
     void log(class QListWidgetItem *entry, enum Status status = STATUS_OK) noexcept;
     void status(const QString &text, long progress = -1) noexcept;
     void status(long progress = -1) noexcept;
     void advance(int space, long steps) noexcept;
-    // Common functions that are traditionally carried out by processes.
-    void sleep(const int msec, const bool silent = false) noexcept;
-    bool mkpath(const QString &path, mode_t mode = 0, bool force = false);
-    // Operating system
-    const QString &detectArch();
-    int detectEFI(bool noTest = false);
-protected:
-    void setupChildProcess() noexcept override;
 
 private:
     friend class ExceptionInfo;
     class Section *section = nullptr;
     int execount = 0;
-    int sleepcount = 0;
     enum HaltMode { NO_HALT, THROW_HALT, HALTED } halting = NO_HALT;
     bool debugUnusedOutput = true;
     class QListWidget *logView = nullptr;
@@ -80,13 +72,10 @@ private:
     int progSliceStart = 0, progSliceSpace = 0;
     long progSlicePos = 0, progSliceSteps = 0;
     int prevScrollMax = 0;
-    // System detection results
-    QString testArch;
-    int testEFI = -1;
     // Common execution core
     bool exec(const QString &program, const QStringList &arguments,
         const QByteArray *input, bool needRead, class QListWidgetItem *logEntry);
-    bool checkHalt();
+    void syncRoot() noexcept;
 };
 
 // A section with specific error handling or chroot requirements.
@@ -104,17 +93,12 @@ public:
     inline Section(class MProcess &mproc, const char *failmessage) noexcept
         : Section(mproc) { failmsg = failmessage; }
     ~Section() noexcept;
-    inline const char *failMessage() noexcept { return failmsg; }
-    inline bool strict() noexcept { return strictfail; }
+    inline const char *failMessage() const noexcept { return failmsg; }
+    inline bool strict() const noexcept { return strictfail; }
     inline void setExceptionMode(const char *message) noexcept { failmsg = message; }
-    inline void setExceptionMode(bool strict) noexcept { strictfail = strict; }
-    inline void setExceptionMode(const char *message, bool strict) noexcept
-    {
-        failmsg = message;
-        strictfail = strict;
-    }
+    inline void setExceptionStrict(bool strict) noexcept { strictfail = strict; }
     void setRoot(const char *newroot) noexcept;
-    inline const char *root() noexcept { return rootdir; }
+    inline const char *root() const noexcept { return rootdir; }
     Section(const Section &) = delete;
     Section &operator=(const Section &) = delete;
 };
